@@ -353,7 +353,7 @@ class NamespaceAssembler(Assembler):
         return Namespace(
             name = Name(dto.name),
             status = Status(dto.status),
-            age = DateTime(dto.age),
+            age = K3SRunTime(dto.age),
             _life_time = Number(dto._life_time)
         )
     def to_dto(self, x: Namespace):
@@ -368,7 +368,7 @@ class SecretAssembler(Assembler):
     def to_entity(self, dto: SecretDTO):
         return Secret(
             name = Name(dto.name),
-            age = DateTime(dto.age),
+            age = K3SRunTime(dto.age),
             namespace = Name(dto.namespace),
             _life_time = Number(dto._life_time)
         )
@@ -400,7 +400,7 @@ class ConfigMapAssembler(Assembler):
     def to_entity(self, dto: ConfigMapDTO):
         return ConfigMap(
             name = Name(dto.name),
-            age = DateTime(dto.age),
+            age = K3SRunTime(dto.age),
             namespace = Name(dto.namespace),
             _life_time = Number(dto._life_time)
         )
@@ -434,7 +434,7 @@ class DeploymentAssembler(Assembler):
     def to_entity(self, dto: DeploymentDTO):
         return Deployment(
             name = Name(dto.name),
-            age = DateTime(dto.age),
+            age = K3SRunTime(dto.age),
             namespace = Name(dto.namespace),
             ready_info = Info(dto.ready_info),
             _life_time = Number(dto._life_time)
@@ -454,7 +454,7 @@ class PodAssembler(Assembler):
             name = Name(dto.name),
             node_name = None if dto.node_name is None else NodeName(dto.node_name),
             pod_status = PodStatus(dto.pod_status),
-            age = DateTime(dto.age),
+            age = K3SRunTime(dto.age),
             pod_ip = None if dto.pod_ip is None else IP(dto.pod_ip),
             namespace = Name(dto.namespace),
             restarts = RestartNumber(dto.restarts),
@@ -517,7 +517,7 @@ class IngressAssembler(Assembler):
             host_info = Info(dto.host_info),
             address_info = Info(dto.address_info),
             port = Number(dto.port),
-            age = DateTime(dto.age),
+            age = K3SRunTime(dto.age),
             namespace = Name(dto.namespace),
             _life_time = Number(dto._life_time)
         )
@@ -540,7 +540,7 @@ class ServiceAssembler(Assembler):
             cluster_ip = IP(dto.cluster_ip),
             external_ip = IP(dto.external_ip),
             port_info = Info(dto.port_info),
-            age = DateTime(dto.age),
+            age = K3SRunTime(dto.age),
             _life_time = Number(dto._life_time)
         )
     def to_dto(self, x: Service):
@@ -869,7 +869,7 @@ class JobAssembler(Assembler):
     def to_entity(self, dto: JobDTO):
         return Job(
             name = Name(dto.name),
-            age = DateTime(dto.age),
+            age = K3SRunTime(dto.age),
             namespace = Name(dto.namespace),
             status = JobStatus(dto.status),
             parallelism = Number(dto.parallelism),
