@@ -66,8 +66,8 @@ class NodeInfoDTO(BaseModel):
     bandwidth_out: int
     node_expired_time: Optional[str]
     auto_release_time: Optional[str]
-    key_name: str
-    run_time: Optional[int]=None
+    key_name: Optional[str]
+    run_time: Optional[float]=None
     k3s_version: Optional[str]=None
     _life_time: int=5
 
@@ -117,7 +117,7 @@ class ConfigMapUserSettingDTO(BaseModel):
 
 class DeploymentDTO(BaseModel):
     name: str
-    age: Union[str, datetime.timedelta]
+    age: float
     namespace: str
     ready_info: str
     _life_time: int=5
@@ -127,7 +127,7 @@ class PodDTO(BaseModel):
     name: str
     node_name: Optional[str]
     pod_status: str
-    age: Union[str, datetime.timedelta]
+    age: float
     pod_ip: Optional[str]
     namespace: str
     restarts: str
@@ -153,7 +153,7 @@ class IngressDTO(BaseModel):
     host_info: str
     address_info: str
     port: int
-    age: Union[str, datetime.timedelta]
+    age: float
     namespace: str
     _life_time: int=5
 
@@ -163,7 +163,7 @@ class ServiceDTO(BaseModel):
     cluster_ip: str
     external_ip: Optional[str]
     port_info: str
-    age: Union[str, datetime.timedelta]
+    age: float
     _life_time: int=5
 
 
