@@ -278,7 +278,7 @@ class Namespace(ExpiredEntity):
         self,
         name: Name,
         status: Status,
-        age: DateTime,
+        age: K3SRunTime,
         _life_time: Number = Number(5)
     ):
         self.name=name
@@ -291,7 +291,7 @@ class Secret(ExpiredEntity):
     def __init__(
         self,
         name: Name,
-        age: DateTime,
+        age: K3SRunTime,
         namespace: Name,
         _life_time: Number = Number(5)
     ):
@@ -333,7 +333,7 @@ class ConfigMap(ExpiredEntity):
     def __init__(
         self,
         name: Name,
-        age: DateTime,
+        age: K3SRunTime,
         namespace: Name,
         _life_time: Number = Number(5)
     ):
@@ -347,7 +347,7 @@ class Deployment(ExpiredEntity):
     def __init__(
         self,
         name: Name,
-        age: DateTime,
+        age: K3SRunTime,
         namespace: Name,
         ready_info: Info,
         _life_time: Number = Number(5)
@@ -365,7 +365,7 @@ class Pod(ExpiredEntity):
         name: Name,
         node_name: Optional[NodeName],
         pod_status: PodStatus,
-        age: DateTime,
+        age: K3SRunTime,
         pod_ip: Optional[IP],
         namespace: Name,
         restarts: RestartNumber,
@@ -421,7 +421,7 @@ class Ingress(ExpiredEntity):
         host_info: Info,
         address_info: Info,
         port: Number,
-        age: DateTime,
+        age: K3SRunTime,
         namespace: Name,
         _life_time: Number = Number(5)
     ):
@@ -442,7 +442,7 @@ class Service(ExpiredEntity):
         cluster_ip: IP,
         external_ip: Optional[IP],
         port_info: Info,
-        age: DateTime,
+        age: K3SRunTime,
         _life_time: Number = Number(5)
     ):
         self.name=name
@@ -752,7 +752,7 @@ class Job(ExpiredEntity):
     def __init__(
         self,
         name: Name,
-        age: DateTime,
+        age: K3SRunTime,
         namespace: Name,
         status: JobStatus,
         parallelism: Number,
