@@ -380,7 +380,7 @@ class NamespaceConverter(Converter):
         return Namespace(
             name = Name(do.name),
             status = Status(do.status),
-            age = DateTime(do.age),
+            age = K3SRunTime(do.age),
             _life_time = Number(do._life_time)
         )
     def to_do(self, x: Namespace):
@@ -398,7 +398,7 @@ class SecretConverter(Converter):
     def to_entity(self, do: SecretDO):
         return Secret(
             name = Name(do.name),
-            age = DateTime(do.age),
+            age = K3SRunTime(do.age),
             namespace = Name(do.namespace),
             _life_time = Number(do._life_time)
         )
@@ -436,7 +436,7 @@ class ConfigMapConverter(Converter):
     def to_entity(self, do: ConfigMapDO):
         return ConfigMap(
             name = Name(do.name),
-            age = DateTime(do.age),
+            age = K3SRunTime(do.age),
             namespace = Name(do.namespace),
             _life_time = Number(do._life_time)
         )
@@ -476,7 +476,7 @@ class DeploymentConverter(Converter):
     def to_entity(self, do: DeploymentDO):
         return Deployment(
             name = Name(do.name),
-            age = DateTime(do.age),
+            age = K3SRunTime(do.age),
             namespace = Name(do.namespace),
             ready_info = Info(do.ready_info),
             _life_time = Number(do._life_time)
@@ -499,7 +499,7 @@ class PodConverter(Converter):
             name = Name(do.name),
             node_name = None if do.node_name is None else NodeName(do.node_name),
             pod_status = PodStatus(do.pod_status),
-            age = DateTime(do.age),
+            age = K3SRunTime(do.age),
             pod_ip = None if do.pod_ip is None else IP(do.pod_ip),
             namespace = Name(do.namespace),
             restarts = RestartNumber(do.restarts),
@@ -529,7 +529,7 @@ class IngressConverter(Converter):
             host_info = Info(do.host_info),
             address_info = Info(do.address_info),
             port = Number(do.port),
-            age = DateTime(do.age),
+            age = K3SRunTime(do.age),
             namespace = Name(do.namespace),
             _life_time = Number(do._life_time)
         )
@@ -555,7 +555,7 @@ class ServiceConverter(Converter):
             cluster_ip = IP(do.cluster_ip),
             external_ip = IP(do.external_ip),
             port_info = Info(do.port_info),
-            age = DateTime(do.age),
+            age = K3SRunTime(do.age),
             _life_time = Number(do._life_time)
         )
     def to_do(self, x: Service):
@@ -982,7 +982,7 @@ class JobConverter(Converter):
     def to_entity(self, do: JobDO):
         return Job(
             name = Name(do.name),
-            age = DateTime(do.age),
+            age = K3SRunTime(do.age),
             namespace = Name(do.namespace),
             status = JobStatus(do.status),
             parallelism = Number(do.parallelism),
