@@ -71,7 +71,7 @@ class NodeInfoDO(BaseModel):
     node_expired_time: Optional[str]=None
     auto_release_time: Optional[str]=None
     key_name: Optional[str]=None
-    run_time: Optional[Union[str, datetime.timedelta]]=None
+    run_time: Optional[float]=None
     k3s_version: Optional[str]=None
     _life_time: int=5
 
@@ -91,13 +91,13 @@ class NodeCreationItemDO(BaseModel):
 class NamespaceDO(BaseModel):
     name: str
     status: str
-    age: Union[str, datetime.timedelta]
+    age: float
     _life_time: int=5
 
 
 class SecretDO(BaseModel):
     name: str
-    age: Union[str, datetime.timedelta]
+    age: float
     namespace: str
     _life_time: int=5
 
@@ -111,7 +111,7 @@ class SecretUserSettingDO(BaseModel):
 
 class ConfigMapDO(BaseModel):
     name: str
-    age: Union[str, datetime.timedelta]
+    age: float
     namespace: str
     _life_time: int=5
 
@@ -126,7 +126,7 @@ class ConfigMapUserSettingDO(BaseModel):
 
 class DeploymentDO(BaseModel):
     name: str
-    age: Union[str, datetime.timedelta]
+    age: float
     namespace: str
     ready_info: str
     _life_time: int=5
@@ -136,7 +136,7 @@ class PodDO(BaseModel):
     name: str
     node_name: Optional[str]
     pod_status: str
-    age: Union[str, datetime.timedelta]
+    age: float
     pod_ip: Optional[str]
     namespace: str
     restarts: str
@@ -149,7 +149,7 @@ class IngressDO(BaseModel):
     host_info: str
     address_info: str
     port: int
-    age: Union[str, datetime.timedelta]
+    age: float
     namespace: str
     _life_time: int=5
 
@@ -160,7 +160,7 @@ class ServiceDO(BaseModel):
     cluster_ip: str
     external_ip: Optional[str]
     port_info: str
-    age: Union[str, datetime.timedelta]
+    age: float
     _life_time: int=5
 
 
@@ -170,18 +170,17 @@ class PodContainerDO(BaseModel):
     container_info: str
     _life_time: int=5
 
+
 class ReleaseNodeInfoDO(BaseModel):
     node_name: str
     region_id: str
     instance_id: str
 
 
-
-
 class NodeMetaDO(BaseModel):
     name: str
     status: str
-    run_time: Union[str, datetime.timedelta]
+    run_time: float
     k3s_version: str
     private_ip: str
     label: Union[str, Dict]
@@ -343,7 +342,7 @@ class JobSettingDO(BaseModel):
 
 class JobDO(BaseModel):
     name: str
-    age: Union[str, datetime.timedelta]
+    age: float
     namespace: str
     status: Dict
     parallelism: int
